==> aws-solutions-constructs.aws-sns-sqs-1.89.0.tar.gz: aws-solutions-constructs.aws-sns-sqs-1.89.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-sns-sqs",
    "version": "1.89.0",
    "description": "CDK constructs for defining an interaction between an Amazon SNS topic and an Amazon SQS queue.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_sns_sqs",
        "aws_solutions_constructs.aws_sns_sqs._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_sns_sqs._jsii": [
            "aws-sns-sqs@1.89.0.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_sns_sqs": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-iam==1.89.0",
        "aws-cdk.aws-kms==1.89.0",
        "aws-cdk.aws-sns-subscriptions==1.89.0",
        "aws-cdk.aws-sns==1.89.0",
        "aws-cdk.aws-sqs==1.89.0",
        "aws-cdk.core==1.89.0",
        "aws-solutions-constructs.core==1.89.0",
        "constructs>=3.2.0, <4.0.0",
        "jsii>=1.22.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-solutions-constructs.aws-sns-sqs-2.0.0rc1.tar.gz: aws-solutions-constructs.aws-sns-sqs-2.0.0rc1/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-solutions-constructs.aws-sns-sqs",
    "version": "2.0.0.rc1",
    "description": "CDK constructs for defining an interaction between an Amazon SNS topic and an Amazon SQS queue.",
    "license": "Apache-2.0",
    "url": "https://github.com/awslabs/aws-solutions-constructs.git",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/awslabs/aws-solutions-constructs.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_solutions_constructs.aws_sns_sqs",
        "aws_solutions_constructs.aws_sns_sqs._jsii"
    ],
    "package_data": {
        "aws_solutions_constructs.aws_sns_sqs._jsii": [
            "aws-sns-sqs@2.0.0-rc.1.jsii.tgz"
        ],
        "aws_solutions_constructs.aws_sns_sqs": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk-lib>=2.0.0.rc23, <3.0.0",
        "aws-solutions-constructs.core==2.0.0.rc1",
        "constructs>=10.0.0, <11.0.0",
        "jsii>=1.39.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "License :: OSI Approved"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
